@@ -86,7 +86,7 @@
 bnpathplot <- function (results, exp, expSample=NULL, algo="hc",
                     algorithm.args=NULL, expRow="ENSEMBL", cl=NULL,
                     returnNet=FALSE, otherVar=NULL, otherVarName=NULL,
-                    qvalueCutOff=0.05, adjpCutOff=0.05, nCategory=15,
+                    qvalueCutOff=NULL, adjpCutOff=0.05, nCategory=15,
                     R=20, interactive=FALSE, color="p.adjust", cexCategory=1,
                     cexLine=0.5, chooseDir=FALSE, showDir=FALSE,
                     delZeroDegree=TRUE, labelSize=4, layout="nicely",
@@ -237,7 +237,7 @@ bnpathplot <- function (results, exp, expSample=NULL, algo="hc",
                 res <- res[!is.na(res$ID),]
             }
     }
-
+    
     ## Some pathway databases have duplicate names
     if (sum(duplicated(res$Description))>0){
         dnames <- res$Description[duplicated(res$Description)]
@@ -254,6 +254,7 @@ bnpathplot <- function (results, exp, expSample=NULL, algo="hc",
     pcs <- c()
     pwayNames <- c()
     pathDep <- c()
+    
     for (i in seq_len(length(rownames(res)))) {
         genesInPathway <- strsplit(res[i, ]$geneID, "/")[[1]]
 
@@ -288,7 +289,7 @@ bnpathplot <- function (results, exp, expSample=NULL, algo="hc",
     if (sizeDep) {names(pathDep) <- res$Description}
     colnames(pcs) <- pwayNames
     pcs <- data.frame(pcs, check.names=FALSE)
-    if (dim(pcs)[1]==0){return("error")}
+    if (dim(pcs)[1]<=1){stop("Zero or one pathway in the resulting matrix.")}
 
 
     if (!is.null(otherVar)) {
@@ -348,7 +349,7 @@ bnpathplot <- function (results, exp, expSample=NULL, algo="hc",
                                                                 width = 25))
     }
 
-    if (dim(strength)[1]==0) {return("error")}
+    if (dim(strength)[1]==0) {stop("Strength data.frame is empty.")}
     ## Average by specified threshold
     if (!useSiGN) {
         if (!is.null(strThresh)){
@@ -372,7 +373,7 @@ bnpathplot <- function (results, exp, expSample=NULL, algo="hc",
 
         g <- bnlearn::as.igraph(av)
         e <- as_edgelist(g, names = TRUE)
-        if (dim(e)[1]==0){message("no edge present in graph");return("error")}
+        if (dim(e)[1]==0){stop("no edge present in graph");}
         eName <-paste0(e[,1], "_", e[,2])
         colnames(e) <- c("from","to")
         eDf <- merge(e, strength)
