@@ -76,7 +76,7 @@ bnpathplotCustom <- function (results, exp, expSample=NULL, algo="hc",
                             cexCategory=1, cl=NULL, showDir=FALSE,
                             chooseDir=FALSE, labelSize=4, layout="nicely",
                             strType="normal", compareRef=FALSE, disc=FALSE,
-                            tr=NULL, remainCont=NULL, qvalueCutOff=0.05,
+                            tr=NULL, remainCont=NULL, qvalueCutOff=NULL,
                             adjpCutOff=0.05, nCategory=15, cexLine=1,
                             returnNet=FALSE, dep=NULL, sizeDep=FALSE,
                             cellLineName="5637_URINARY_TRACT",
@@ -192,7 +192,7 @@ bnpathplotCustom <- function (results, exp, expSample=NULL, algo="hc",
     colnames(pcs) <- pwayNames
 
     pcs <- data.frame(pcs, check.names=FALSE)
-    if (dim(pcs)[1]==0){return("error")}
+    if (dim(pcs)[1]<=1){stop("Zero or one pathway present in the resulting matrix.")}
     
     if (!is.null(otherVar)) {
         pcs <- cbind(pcs, otherVar)
